import request from '@/utils/request'

//查询志愿者提现申请记录列表
export function takeList(query) {
  return request({
    url: '/core/volunteer/take/list',
    method: 'get',
    params: query
  })
}
//查询志愿者打款单记录列表
export function paymentList(query) {
    return request({
      url: '/core/volunteer/payment/list',
      method: 'get',
      params: query
    })
  }
  

  //提现审批
  export function takeApproval(data) {
      return request({
        url: `/core/volunteer/take/approval`,
        method: 'post',
        data
      })
    }
 
    //创建志愿者打款单
    export function careatPayment(data) {
        return request({
          url: `/core/volunteer/payment`,
          method: 'post',
          data
        })
      }
    
      
//打款单验证
      export function payoutCheck(data) {
        return request({
          url: `/core/volunteer/payment/payoutCheck`,
          method: 'post',
          data
        })
      }